..  -*- coding: utf-8 -*-

.. _contents:

Overview of NetworkX_
=====================

.. _NetworkX: https://networkx.github.io/

NetworkX is a Python package for the creation, manipulation, and study
of the structure, dynamics, and functions of complex networks.

NetworkX provides:

-  tools for the study of the structure and
   dynamics of social, biological, and infrastructure networks;
-  a standard programming interface and graph implementation that is suitable
   for many applications;
-  a rapid development environment for collaborative, multidisciplinary
   projects;
-  an interface to existing numerical algorithms and code written in C,
   C++, and FORTRAN; and
-  the ability to painlessly work with large nonstandard data sets.

With NetworkX you can load and store networks in standard and nonstandard data
formats, generate many types of random and classic networks, analyze network
structure, build network models, design new network algorithms, draw networks,
and much more.

Audience
--------

The audience for NetworkX includes mathematicians, physicists, biologists,
computer scientists, and social scientists. Good reviews of the science of
complex networks are presented in Albert and Barabási [BA02]_, Newman
[Newman03]_, and Dorogovtsev and Mendes [DM03]_. See also the classic texts
[Bollobas01]_, [Diestel97]_ and [West01]_ for graph theoretic results and
terminology. For basic graph algorithms, we recommend the texts of Sedgewick
(e.g., [Sedgewick01]_ and [Sedgewick02]_) and the survey of Brandes and
Erlebach [BE05]_.

Python
------

Python is a powerful programming language that allows simple and flexible
representations of networks as well as clear and concise expressions of network
algorithms.  Python has a vibrant and growing ecosystem of packages that
NetworkX uses to provide more features such as numerical linear algebra and
drawing.  In order to make the most out of NetworkX you will want to know how
to write basic programs in Python.  Among the many guides to Python, we
recommend the `Python documentation <https://docs.python.org/3/>`_ and the text
by Alex Martelli [Martelli03]_.

Free software
-------------

NetworkX is free software; you can redistribute it and/or modify it under the
terms of the :doc:`3-clause BSD License </license>`.  We welcome contributions.
Join us on `GitHub <https://github.com/networkx/networkx>`_.

History
-------

NetworkX was born in May 2002. The original version was designed and written by
Aric Hagberg, Dan Schult, and Pieter Swart in 2002 and 2003.  The first public
release was in April 2005.
Many people have contributed to the success of NetworkX. Some of the
contributors are listed in the :doc:`credits. <credits>`

Documentation
-------------

.. only:: html

    :Release: |version|
    :Date: |today|

.. toctree::
   :maxdepth: 1

   install
   tutorial
   reference/index
   developer/index
   news
   license
   credits
   citing
   bibliography
   auto_examples/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
